@@ -44,6 +44,7 @@
 #include "panel-properties-dialog.h"
 #include "panel-lockdown.h"
 #include "panel-addto.h"
+#include "panel-icon-names.h"
 
 static void
 panel_context_menu_show_help (GtkWidget *w,
@@ -96,7 +97,7 @@ panel_context_menu_show_about_dialog (GtkWidget *menuitem)
 		"Seth Nickell (snickell@stanford.edu)",
 		"Stephen Browne (stephen.browne@sun.com)",
 		"Tom Tromey (tromey@cygnus.com)",
-		"Vincent Untz (vincent@vuntz.net)",
+		"Vincent Untz (vuntz@gnome.org)",
 		N_("And many, many others..."),
 		NULL
 	};
@@ -123,18 +124,17 @@ panel_context_menu_show_about_dialog (GtkWidget *menuitem)
 	 * dialog */
 	about = gtk_about_dialog_new ();
 	g_object_set (about,
-		      "name",  _("The GNOME Panel"),
+		      "program-name",  _("The GNOME Panel"),
 		      "version", VERSION,
 		      "copyright", "Copyright \xc2\xa9 1997-2003 Free Software Foundation, Inc.",
 		      "comments", _("This program is responsible for launching other "
-				    "applications and embedding small applets within itself."),
+				    "applications and provides useful utilities."),
 		      "authors", authors,
 		      "documenters", documenters,
 		      "translator-credits", _("translator-credits"),
-		      "logo-icon-name", "gnome-panel",
+		      "logo-icon-name", PANEL_ICON_PANEL,
 		      NULL);
 
-	gtk_window_set_wmclass (GTK_WINDOW (about), "about_dialog", "Panel");
 	gtk_window_set_screen (GTK_WINDOW (about),
 			       menuitem_to_screen (menuitem));
 	g_signal_connect (about, "destroy",
@@ -158,18 +158,12 @@ panel_context_menu_create_new_panel (GtkWidget *menuitem)
 }
 
 static void
-panel_context_menu_remove_panel (GtkWidget *menuitem,
-				 gpointer data)
+panel_context_menu_delete_panel (PanelToplevel *toplevel)
 {
-	PanelWidget   *panel_widget;
-	PanelToplevel *toplevel;
-
-	panel_widget = menu_get_panel (menuitem);
-	toplevel     = panel_widget->toplevel;
-
 	if (panel_toplevel_is_last_unattached (toplevel)) {
-		panel_error_dialog (menuitem_to_screen (menuitem),
-				    "cannot_remove_last_panel", TRUE,
+		panel_error_dialog (GTK_WINDOW (toplevel),
+				    gtk_window_get_screen (GTK_WINDOW (toplevel)),
+				    "cannot_delete_last_panel", TRUE,
 				    _("Cannot delete this panel"),
 				    _("You must always have at least one panel."));
 		return;
@@ -179,11 +173,10 @@ panel_context_menu_remove_panel (GtkWidget *menuitem,
 }
 
 static void
-panel_context_menu_setup_remove_panel_item (GtkWidget *menu,
+panel_context_menu_setup_delete_panel_item (GtkWidget *menu,
 					    GtkWidget *menuitem)
 {
 	PanelWidget *panel_widget;
-	GtkWidget   *label;
 	gboolean     sensitive;
 
 	panel_widget = menu_get_panel (menu);
@@ -196,93 +189,55 @@ panel_context_menu_setup_remove_panel_item (GtkWidget *menu,
 		panel_profile_id_lists_are_writable ();
 
 	gtk_widget_set_sensitive (menuitem, sensitive);
-
-	label = GTK_BIN (menuitem)->child;
-	if (GTK_IS_BOX (label)) {
-		GList *li, *list;
-		list = gtk_container_get_children (GTK_CONTAINER (label));
-		for (li = list; li; li = li->next) {
-			if (GTK_IS_LABEL (li->data)) {
-				label = li->data;
-				break;
-			}
-		}
-		g_list_free (list);
-	}
-	if (!GTK_IS_LABEL (label)) {
-		g_warning ("We can't find the label of a menu item");
-		return;
-	}
-
-	/* this will not handle the case of menu being torn off
-	 * and then the confirm_panel_remove changed, but oh well */
-	if (panel_widget->applet_list &&
-	    panel_global_config_get_confirm_panel_remove ())
-		gtk_label_set_text_with_mnemonic (GTK_LABEL (label),
-						  _("_Delete This Panel..."));
-	else
-		gtk_label_set_text_with_mnemonic (GTK_LABEL (label),
-						  _("_Delete This Panel"));
 }
 
 static void
-make_panel_submenu (PanelWidget *panel_widget,
-		    GtkWidget   *menu)
+panel_context_menu_build_edition (PanelWidget *panel_widget,
+				  GtkWidget   *menu)
 {
 	GtkWidget *menuitem;
+	GtkWidget *image;
 
-	menuitem = gtk_image_menu_item_new ();
-	setup_menuitem (menuitem,
-			GTK_ICON_SIZE_MENU,
-			gtk_image_new_from_stock (GTK_STOCK_ADD,
-						  GTK_ICON_SIZE_MENU),
-			_("_Add to Panel..."),
-			FALSE);
+	menuitem = gtk_image_menu_item_new_with_mnemonic (_("_Add to Panel..."));
+	image = gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
+	gtk_widget_show (menuitem);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-
         g_signal_connect (G_OBJECT (menuitem), "activate",
 	      	       	  G_CALLBACK (panel_addto_present), panel_widget);
 
 	if (!panel_profile_id_lists_are_writable ())
 		gtk_widget_set_sensitive (menuitem, FALSE);
 
-	menuitem = gtk_image_menu_item_new ();
-	setup_menuitem (menuitem,
-			GTK_ICON_SIZE_MENU,
-			gtk_image_new_from_stock (GTK_STOCK_PROPERTIES,
-						  GTK_ICON_SIZE_MENU),
-			_("_Properties"),
-			FALSE);
-
+	menuitem = gtk_image_menu_item_new_with_mnemonic (_("_Properties"));
+	image = gtk_image_new_from_stock (GTK_STOCK_PROPERTIES,
+					  GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
+	gtk_widget_show (menuitem);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect_swapped (menuitem, "activate",
 				  G_CALLBACK (panel_properties_dialog_present), 
 				  panel_widget->toplevel);
 
-	menuitem = gtk_image_menu_item_new ();
-	setup_menuitem (menuitem, 
-			GTK_ICON_SIZE_MENU,
-			gtk_image_new_from_stock (GTK_STOCK_DELETE,
-						  GTK_ICON_SIZE_MENU),
-			_("_Delete This Panel"),
-			FALSE);
+	menuitem = gtk_image_menu_item_new_with_mnemonic (_("_Delete This Panel"));
+	image = gtk_image_new_from_stock (GTK_STOCK_DELETE,
+					  GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
+	gtk_widget_show (menuitem);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	g_signal_connect (G_OBJECT (menuitem), "activate",
-			  G_CALLBACK (panel_context_menu_remove_panel),
-			  NULL);
+	g_signal_connect_swapped (G_OBJECT (menuitem), "activate",
+				  G_CALLBACK (panel_context_menu_delete_panel),
+				  panel_widget->toplevel);
 	g_signal_connect (G_OBJECT (menu), "show",
-			  G_CALLBACK (panel_context_menu_setup_remove_panel_item),
+			  G_CALLBACK (panel_context_menu_setup_delete_panel_item),
 			  menuitem);
 
 	add_menu_separator (menu);
 
-	menuitem = gtk_image_menu_item_new ();
-	setup_menuitem (menuitem, 
-			GTK_ICON_SIZE_MENU,
-			gtk_image_new_from_stock (GTK_STOCK_NEW,
-						  GTK_ICON_SIZE_MENU),
-			_("_New Panel"),
-			FALSE);
+	menuitem = gtk_image_menu_item_new_with_mnemonic (_("_New Panel"));
+	image = gtk_image_new_from_stock (GTK_STOCK_NEW, GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
+	gtk_widget_show (menuitem);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK (panel_context_menu_create_new_panel), 
@@ -298,6 +253,7 @@ panel_context_menu_create (PanelWidget *panel)
 {
 	GtkWidget *retval;
 	GtkWidget *menuitem;
+	GtkWidget *image;
 
 	if (panel->master_widget) {
 		gpointer    *pointer;
@@ -319,31 +275,27 @@ panel_context_menu_create (PanelWidget *panel)
 	retval = create_empty_menu ();
 
 	if (!panel_lockdown_get_locked_down ())
-		make_panel_submenu (panel, retval);
+		panel_context_menu_build_edition (panel, retval);
 
-	menuitem = gtk_image_menu_item_new ();
-	setup_menuitem (menuitem,
-			GTK_ICON_SIZE_MENU,
-			gtk_image_new_from_stock (GTK_STOCK_HELP,
-						  GTK_ICON_SIZE_MENU),
-			_("_Help"),
-			FALSE);
+	menuitem = gtk_image_menu_item_new_with_mnemonic (_("_Help"));
+	image = gtk_image_new_from_stock (GTK_STOCK_HELP, GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
+	gtk_widget_show (menuitem);
 	gtk_menu_shell_append (GTK_MENU_SHELL (retval), menuitem);
 	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK (panel_context_menu_show_help), NULL);
 
-	menuitem = gtk_image_menu_item_new ();
-	setup_menuitem (menuitem,
-			GTK_ICON_SIZE_MENU,
-			gtk_image_new_from_stock (GTK_STOCK_ABOUT,
-						  GTK_ICON_SIZE_MENU),
-			_("A_bout Panels"),
-			FALSE);
+	menuitem = gtk_image_menu_item_new_with_mnemonic (_("A_bout Panels"));
+	image = gtk_image_new_from_stock (GTK_STOCK_ABOUT,
+					  GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
+	gtk_widget_show (menuitem);
 	gtk_menu_shell_append (GTK_MENU_SHELL (retval), menuitem);
 	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK (panel_context_menu_show_about_dialog),
 			  NULL);
 	
+	//FIXME: can we get rid of this? (needed by menu_get_panel())
 	g_object_set_data (G_OBJECT (retval), "menu_panel", panel);
 
 	return retval;
