@@ -29,6 +29,8 @@
 #include <string.h>
 #include <glib/gi18n.h>
 
+#include <gmenu-tree.h>
+
 #include "applet.h"
 #include "panel-widget.h"
 #include "panel-util.h"
@@ -37,6 +39,9 @@
 #include "menu.h"
 #include "panel-lockdown.h"
 #include "panel-a11y.h"
+#include "panel-icon-names.h"
+
+G_DEFINE_TYPE (PanelMenuButton, panel_menu_button, BUTTON_TYPE_WIDGET)
 
 #define PANEL_MENU_BUTTON_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_MENU_BUTTON, PanelMenuButtonPrivate))
 
@@ -92,8 +97,6 @@ static void panel_menu_button_set_icon              (PanelMenuButton *button);
 
 static AtkObject *panel_menu_button_get_accessible  (GtkWidget       *widget);
 
-static GObjectClass *parent_class;
-
 static const char *
 panel_menu_path_root_to_filename (MenuPathRoot path_root)
 {
@@ -159,8 +162,7 @@ panel_menu_scheme_to_path_root (const char *scheme)
 }
 
 static void
-panel_menu_button_instance_init (PanelMenuButton      *button,
-				 PanelMenuButtonClass *klass)
+panel_menu_button_init (PanelMenuButton *button)
 {
 	button->priv = PANEL_MENU_BUTTON_GET_PRIVATE (button);
 
@@ -205,7 +207,7 @@ panel_menu_button_finalize (GObject *object)
 	g_free (button->priv->tooltip);
 	button->priv->tooltip = NULL;
 
-	parent_class->finalize (object);
+	G_OBJECT_CLASS (panel_menu_button_parent_class)->finalize (object);
 }
 
 static void
@@ -312,8 +314,8 @@ panel_menu_button_parent_set (GtkWidget *widget,
 	panel_menu_button_associate_panel (button);
 	panel_menu_button_set_icon (button);
 
-	if (GTK_WIDGET_CLASS (parent_class)->parent_set)
-		GTK_WIDGET_CLASS (parent_class)->parent_set (widget, previous_parent);
+	if (GTK_WIDGET_CLASS (panel_menu_button_parent_class)->parent_set)
+		GTK_WIDGET_CLASS (panel_menu_button_parent_class)->parent_set (widget, previous_parent);
 }
 
 static void
@@ -342,7 +344,7 @@ panel_menu_button_menu_deactivated (PanelMenuButton *button)
 	panel_toplevel_pop_autohide_disabler (button->priv->toplevel);
 
 	GTK_BUTTON (button)->in_button = FALSE;
-	BUTTON_WIDGET (button)->ignore_leave = FALSE;
+	button_widget_set_ignore_leave (BUTTON_WIDGET (button), FALSE);
 	gtk_button_released (GTK_BUTTON (button));
 }
 
@@ -418,7 +420,7 @@ panel_menu_button_popup_menu (PanelMenuButton *button,
 
 	panel_toplevel_push_autohide_disabler (button->priv->toplevel);
 
-	BUTTON_WIDGET (button)->ignore_leave = TRUE;
+	button_widget_set_ignore_leave (BUTTON_WIDGET (button), TRUE);
 
 	screen = gtk_window_get_screen (GTK_WINDOW (button->priv->toplevel));
 	gtk_menu_set_screen (GTK_MENU (button->priv->menu), screen);
@@ -441,8 +443,8 @@ panel_menu_button_pressed (GtkButton *gtk_button)
 
 	button = PANEL_MENU_BUTTON (gtk_button);
 
-	if (GTK_BUTTON_CLASS (parent_class)->pressed)
-		GTK_BUTTON_CLASS (parent_class)->pressed (gtk_button);
+	if (GTK_BUTTON_CLASS (panel_menu_button_parent_class)->pressed)
+		GTK_BUTTON_CLASS (panel_menu_button_parent_class)->pressed (gtk_button);
 
 	panel_menu_button_popup_menu (button, 0, gtk_get_current_event_time());
 }
@@ -457,8 +459,8 @@ panel_menu_button_clicked (GtkButton *gtk_button)
 
 	button = PANEL_MENU_BUTTON (gtk_button);
 
-	if (GTK_BUTTON_CLASS (parent_class)->clicked)
-		GTK_BUTTON_CLASS (parent_class)->clicked (gtk_button);
+	if (GTK_BUTTON_CLASS (panel_menu_button_parent_class)->clicked)
+		GTK_BUTTON_CLASS (panel_menu_button_parent_class)->clicked (gtk_button);
 
 	if ((event = gtk_get_current_event ())) {
 		panel_menu_button_popup_menu (button,
@@ -477,8 +479,6 @@ panel_menu_button_class_init (PanelMenuButtonClass *klass)
 	GtkWidgetClass *widget_class  = (GtkWidgetClass *) klass;
 	GtkButtonClass *button_class  = (GtkButtonClass *) klass;
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	gobject_class->finalize     = panel_menu_button_finalize;
 	gobject_class->get_property = panel_menu_button_get_property;
 	gobject_class->set_property = panel_menu_button_set_property;
@@ -547,32 +547,6 @@ panel_menu_button_class_init (PanelMenuButtonClass *klass)
 					      G_PARAM_READWRITE));
 }
 
-GType
-panel_menu_button_get_type (void)
-{
-	static GType type = 0;
-
-	if (!type) {
-		static const GTypeInfo info = {
-			sizeof (PanelMenuButtonClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) panel_menu_button_class_init,
-			NULL,
-			NULL,
-			sizeof (PanelMenuButton),
-			0,
-			(GInstanceInitFunc) panel_menu_button_instance_init,
-			NULL
-		};
-
-		type = g_type_register_static (
-				BUTTON_TYPE_WIDGET, "PanelMenuButton", &info, 0);
-	}
-
-	return type;
-}
-
 static void
 panel_menu_button_gconf_notify (GConfClient     *client,
 				guint            cnxn_id,
@@ -736,7 +710,7 @@ panel_menu_button_get_icon (PanelMenuButton *button)
 	}
 
 	if (!retval)
-		retval = g_strdup (PANEL_MAIN_MENU_ICON);
+		retval = g_strdup (PANEL_ICON_MAIN_MENU);
 
 	return retval;
 }
@@ -840,8 +814,7 @@ panel_menu_button_set_tooltip (PanelMenuButton *button,
 
 	if (tooltip && tooltip [0]) {
 		button->priv->tooltip = g_strdup (tooltip);
-		gtk_tooltips_set_tip (panel_tooltips, GTK_WIDGET (button),
-				      tooltip, NULL);
+		panel_util_set_tooltip_text (GTK_WIDGET (button), tooltip);
 	}
 }
 
@@ -1215,5 +1188,5 @@ panel_menu_button_get_accessible (GtkWidget *widget)
 
 	first_time = FALSE;
 	 
-	return GTK_WIDGET_CLASS (parent_class)->get_accessible (widget);
+	return GTK_WIDGET_CLASS (panel_menu_button_parent_class)->get_accessible (widget);
 }
